FL.objects.Glyph.Glyph
======================

.. currentmodule:: FL.objects.Glyph

.. autoclass:: Glyph
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Glyph.Add
      ~Glyph.Assign
      ~Glyph.Audit
      ~Glyph.Autohint
      ~Glyph.Badd
      ~Glyph.Bintersect
      ~Glyph.Blend
      ~Glyph.Bsubtract
      ~Glyph.Clear
      ~Glyph.College
      ~Glyph.Decompose
      ~Glyph.Delete
      ~Glyph.DeleteContour
      ~Glyph.DeleteNode
      ~Glyph.DeleteSelected
      ~Glyph.Distance
      ~Glyph.EditMask
      ~Glyph.ExchangeMask
      ~Glyph.ExpandLayer
      ~Glyph.Extrude3D
      ~Glyph.FindAnchor
      ~Glyph.FindContour
      ~Glyph.GetBoundingRect
      ~Glyph.GetContourBegin
      ~Glyph.GetContourLength
      ~Glyph.GetContoursNumber
      ~Glyph.GetMetrics
      ~Glyph.GetVSB
      ~Glyph.Gradient
      ~Glyph.Insert
      ~Glyph.InsertNode
      ~Glyph.Interpolate
      ~Glyph.InvertSelection
      ~Glyph.Iterate
      ~Glyph.JoinAll
      ~Glyph.Layer
      ~Glyph.LoadEPS
      ~Glyph.MakeExtremeNodes
      ~Glyph.MoveNode
      ~Glyph.Present
      ~Glyph.R
      ~Glyph.Rasterize
      ~Glyph.RemoveHints
      ~Glyph.RemoveOverlap
      ~Glyph.ReorderContour
      ~Glyph.ReverseContour
      ~Glyph.Rotate3D
      ~Glyph.SaveEPS
      ~Glyph.Scale
      ~Glyph.Section
      ~Glyph.SelectAll
      ~Glyph.SelectContour
      ~Glyph.SelectRect
      ~Glyph.SelectedCount
      ~Glyph.Selection
      ~Glyph.SetLayersNumber
      ~Glyph.SetMetrics
      ~Glyph.SetStartNode
      ~Glyph.SetVSB
      ~Glyph.Shadow
      ~Glyph.Shift
      ~Glyph.Transform
      ~Glyph.UnselectAll
      ~Glyph.UnselectRect
      ~Glyph.Warp
      ~Glyph.__init__
      ~Glyph.clear
      ~Glyph.fake_deserialize
      ~Glyph.fake_serialize
      ~Glyph.fake_update
      ~Glyph.isAnySelected
      ~Glyph.isContourClockwise
      ~Glyph.set_defaults
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Glyph.anchors
      ~Glyph.bounding_box
      ~Glyph.components
      ~Glyph.height
      ~Glyph.hguides
      ~Glyph.hhints
      ~Glyph.hlinks
      ~Glyph.index
      ~Glyph.kerning
      ~Glyph.layers_number
      ~Glyph.mask
      ~Glyph.nodes
      ~Glyph.nodes_number
      ~Glyph.parent
      ~Glyph.replace_table
      ~Glyph.unicode
      ~Glyph.vguides
      ~Glyph.vhints
      ~Glyph.vlinks
      ~Glyph.width
   
   